import React, { FC, ReactNode } from 'react';
import { Text, TouchableOpacity } from 'react-native';

import { styles } from './styles';
import { ButtonVariants } from '../../types/components';

type Props = {
  children?: ReactNode;
  variant?: ButtonVariants;
  onPress?: () => void;
};

export const Button: FC<Props> = ({ children, variant, onPress }) => {
  return (
    <>
      {variant === ButtonVariants.OPACITY ? (
        <OpacityButton onPress={onPress} children={children} />
      ) : variant === ButtonVariants.FILL ? (
        <FillButton onPress={onPress} children={children} />
      ) : variant == ButtonVariants.TEXT ? (
        <TextButton children={children} onPress={onPress} />
      ) : (
        <FillButton onPress={onPress} children={children} />
      )}
    </>
  );
};

type VariantProps = {
  children?: ReactNode;
  onPress?: () => void;
};

const OpacityButton: FC<VariantProps> = ({ onPress, children }) => (
  <TouchableOpacity style={[styles.button, styles.opacityButton]} onPress={onPress}>
    <Text style={[styles.text, styles.opacityText]}>{children}</Text>
  </TouchableOpacity>
);

const FillButton: FC<VariantProps> = ({ onPress, children }) => (
  <TouchableOpacity style={[styles.button, styles.fillButton]} onPress={onPress}>
    <Text style={[styles.text, styles.fillText]}>{children}</Text>
  </TouchableOpacity>
);

const TextButton: FC<VariantProps> = ({ onPress, children }) => (
  <TouchableOpacity style={styles.button} onPress={onPress}>
    <Text style={[styles.text, styles.textButtonText]}>{children}</Text>
  </TouchableOpacity>
);
